#
# spec file for package oorexx
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define _rexxpath %{_datadir}/ooRexx
Name:           ooRexx
Version:        5.1.0
Release:        1.1
Summary:        Open Object REXX
License:        CPL-1.0
Group:          Development/Languages/Other
URL:            https://www.rexxla.org
Source0:         https://master.dl.sourceforge.net/project/oorexx/oorexx/5.1.0/oorexx-5.1.0-12973.tar.gz
Source1:        ooRexx-rpmlintrc
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  ncurses-devel
Requires(post): %{_sbindir}/update-alternatives
Requires(postun): %{_sbindir}/update-alternatives
Obsoletes:      ooRexx <= 4.2.0
Provides:       ooRexx = %{version}
Requires:       liboorexx4 = %{version}

%description
Open Object Rexx is an object-oriented scripting language. The language is designed for both beginners and experienced Rexx programmers. It is easy to learn and use, and provides an excellent vehicle to enter the
world of object-oriented programming without much effort.

It extends the procedural way of Rexx programming with object-oriented features that allow you to gradually change your programming style as you learn more about objects.

For more information on ooRexx, visit http://www.oorexx.org/
For more information on Rexx, visit http://www.rexxla.org/

%package devel
Summary:        Open Object REXX development files
Group:          Development/Languages/Other
BuildArch:      noarch

%package -n liboorexx4
Summary:        Open Object REXX libraries
Group:          Development/Languages/Other

%description devel
Development files for Open Object Rexx. These are intended for developing REXX extensions only.

%description -n liboorexx4
Library files for Open Object Rexx.

%prep
%autosetup -n oorexx-5.1.0-12973

%build
# reproducible builds: https://sourceforge.net/p/oorexx/bugs/1712/
setarch -R

# disable optimizations that could cause segfaults in REXX threading
export CFLAGS="-Og"
export CXXFLAGS="-Og"

%cmake -DORX_REXXPATH=%{_rexxpath} -DORX_SHEBANG=%{_bindir}/rexx -DBUILD_RPM=1
%cmake_build

%install
%cmake_install

# create a pkgconfig file
mkdir -p %{buildroot}%{_datadir}/pkgconfig
cat > %{buildroot}%{_datadir}/pkgconfig/%{name}.pc << EOF
prefix=%{_prefix}
exec_prefix=%{_prefix}
libdir=%{_libdir}
includedir=%{_includedir}

%{name}_binary_version=%{version}
%{name}_major=$(echo %{version} | cut -d. -f1)
%{name}_minor=$(echo %{version} | cut -d. -f2)

Name: %{name}
Description: Open Object Rexx
Version: %{version}
Libs: -L\${libdir} -lrexx -lrexxapi
Cflags: -I\${includedir}
EOF

mkdir -p %{buildroot}%{_sysconfdir}/rpm
cat > %{buildroot}%{_sysconfdir}/rpm/oorexx.macros << EOF
%{_ooRexx}        $(echo %{version} | cut -d. -f1)
%{_rexxclassdir}  %{_rexxpath}
%{_rexxlibdir}    %{_libdir}
EOF

# adding update-alternatives support (boo#1083875)
mkdir -p %{buildroot}%{_sysconfdir}/alternatives

# rexxc and rxsubcom need to be renamed upstream! rexx and rxqueue are okay already.
mv %{buildroot}/%{_bindir}/rexx %{buildroot}/%{_bindir}/rexx-oorexx
mv %{buildroot}/%{_bindir}/rexxc %{buildroot}/%{_bindir}/rexxc-oorexx
mv %{buildroot}/%{_bindir}/rxsubcom %{buildroot}/%{_bindir}/rxsubcom-oorexx
mv %{buildroot}/%{_bindir}/rxqueue %{buildroot}/%{_bindir}/rxqueue-oorexx

ln -s  %{_sysconfdir}/alternatives/rexx %{buildroot}%{_bindir}/rexx
ln -s  %{_sysconfdir}/alternatives/rexxc %{buildroot}%{_bindir}/rexxc
ln -s  %{_sysconfdir}/alternatives/rxqueue %{buildroot}%{_bindir}/rxqueue
ln -s  %{_sysconfdir}/alternatives/rxsubcom %{buildroot}%{_bindir}/rxsubcom

# removing binary samples to avoid OBS warnings
rm %{buildroot}%{_datadir}/ooRexx/samples/api/c++/callsample/{runRexxProgram,stackOverflow}
rm %{buildroot}%{_datadir}/ooRexx/samples/api/c++/external/libexternal*so
rm %{buildroot}%{_datadir}/ooRexx/samples/api/classic/callrexx/callrexx*
rm %{buildroot}%{_datadir}/ooRexx/samples/api/classic/rexxapi*/librexxapi*.so

%check

%post
update-alternatives --install %{_bindir}/rexx rexx %{_bindir}/rexx-oorexx 20
update-alternatives --install %{_bindir}/rexxc rexxc %{_bindir}/rexxc-oorexx 20
update-alternatives --install %{_bindir}/rxqueue rxqueue %{_bindir}/rxqueue-oorexx 20
update-alternatives --install %{_bindir}/rxsubcom rxsubcom %{_bindir}/rxsubcom-oorexx 20

%postun
if [ ! -f %{_bindir}/rexx-oorexx ] ; then
  update-alternatives --remove rexx %{_bindir}/rexx-oorexx
fi

if [ ! -f %{_bindir}/rexxc-oorexx ] ; then
  update-alternatives --remove rexxc %{_bindir}/rexxc-oorexx
fi

if [ ! -f %{_bindir}/rxqueue-oorexx ] ; then
  update-alternatives --remove rxqueue %{_bindir}/rxqueue-oorexx
fi

if [ ! -f %{_bindir}/rxsubcom-oorexx ] ; then
  update-alternatives --remove rxsubcom %{_bindir}/rxsubcom-oorexx
fi

%post -n liboorexx4 -p /sbin/ldconfig
%postun -n liboorexx4 -p /sbin/ldconfig

%files
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/48x48
%dir %{_datadir}/icons/hicolor/48x48/apps
%dir %{_datadir}/ooRexx

%{_mandir}/man1/*
%{_datadir}/applications/*
%{_datadir}/icons/hicolor/48x48/apps/*

%{_libdir}/rexx.img
%{_bindir}/rexxtry.rex
%{_bindir}/rxapi
%{_bindir}/rexx-oorexx
%{_bindir}/rexxc-oorexx
%{_bindir}/rxqueue-oorexx
%{_bindir}/rxsubcom-oorexx
%{_bindir}/*cls

%ghost %{_bindir}/rexx
%ghost %{_bindir}/rexxc
%ghost %{_bindir}/rxqueue
%ghost %{_bindir}/rxsubcom

%ghost %attr(0755,root,root) %{_sysconfdir}/alternatives/rexx
%ghost %attr(0755,root,root) %{_sysconfdir}/alternatives/rexxc
%ghost %attr(0755,root,root) %{_sysconfdir}/alternatives/rxqueue
%ghost %attr(0755,root,root) %{_sysconfdir}/alternatives/rxsubcom
%ghost %attr(0644,root,root) %{_sysconfdir}/alternatives/rexx.1
%ghost %attr(0644,root,root) %{_sysconfdir}/alternatives/rexxc.1
%ghost %attr(0644,root,root) %{_sysconfdir}/alternatives/rxqueue.1
%ghost %attr(0644,root,root) %{_sysconfdir}/alternatives/rxsubcom.1

%files -n liboorexx4
%{_libdir}/lib*

%files devel
%config %{_sysconfdir}/rpm/*
%{_includedir}/*
%{_datadir}/pkgconfig/*

%dir %{_datadir}/ooRexx/samples
%{_datadir}/ooRexx/samples/*

%changelog
* Mon May  5 2025 Erico Mendonca <erico.mendonca@suse.com>
- New build for 5.1.0 with latest release tarball.
- Using standard OBS cmake macros.
- Disabling optimizations that can cause segfaults on threading.
- Major changes in this version (complete list in CHANGES file):
  * New TraceObject class (cf. 5.4.25. in rexxref.pdf)
  * 72 bugs solved
  * 35 documentation bugs solved
  * 36 new requests for enhancements implemented
* Thu Feb 27 2025 Erico Mendonca <erico.mendonca@suse.com>
- Renaming package to ooRexx to keep in sync with previous package.
- ooRexx-chdir-setgroups.patch: not needed for version 5.0 codebase
- set_default_rexx_path.patch: not needed for version 5.0 codebase
- systemd-fixes.patches: not needed for version 5.0 codebase
- ooRexx-4.2.0-gcc6.patch: not needed for version 5.0 codebase
- ooRexx-rpmlintrc: exceptions need to be made due to the way REXX libraries
  and classes work (they are not devel files).
* Mon Dec 30 2024 Erico Mendonca <erico.mendonca@suse.com>
- Update to new upstream release 5.0.0:
  * New Keyword instructions
  * New Built-in functions
  * Added notation for namespace and arrays
  * New Directives (ANNOTATE, ABSTRACT, DELEGATE, CONSTANT, OPTIONS, RESOURCE)
  * Changes to classes and methods
  * New functions in Rexxutil library
  * New environment variables
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Oct 15 2021 Erico Mendonca <erico.mendonca@suse.com>
- bsc#1191085: re-adding rc* service sbin links with macros.
* Sat Oct  9 2021 Erico Mendonca <erico.mendonca@suse.com>
- bsc#1191085: removing rc* service sbin links for UsrMerge compatibility.
* Sat Jun  5 2021 Erico Mendonca <erico.mendonca@suse.com>
- Fixing build on latest tumbleweed by forcing C11 mode.
* Wed May  5 2021 Erico Mendonca <erico.mendonca@suse.com>
- boo#1185665: moving the RPM macros to the proper directory.
* Thu Oct 11 2018 Erico Mendonca <erico.mendonca@suse.com>
- Part of the GCC6 fixes broke the SysFileSearch() function. The pointer comparison
  to '\0' needs to be done in the rexxutil library, as the result is returned via a null-delimited string.
  Thus, the -fpermissive flag needs to be added.
* Wed Jun 27 2018 erico.mendonca@suse.com
-  boo#1083875: removing unneeded attributes from /etc/alternatives entries.
* Tue Jun 26 2018 erico.mendonca@suse.com
- boo#1083875: update-alternatives support re-done to avoid conflicts with Regina REXX.
* Wed Mar 14 2018 erico.mendonca@suse.com
- boo#1083875: adding update-alternatives support.
* Wed Dec  6 2017 erico.mendonca@suse.com
- ooRexx-4.2.0-gcc6.patch: Updated to fix compilation errors on rexxutil with GCC6.
* Tue Jan  3 2017 erico.mendonca@suse.com
- boo#1017668: killing leftover "rexximage" process.
* Thu Dec 22 2016 perry.werneck@gmail.com
- ooRexx 4.2 depends on libstdc++6; fixing this on deb packages.
* Fri Dec  2 2016 erico.mendonca@suse.com
- boo#1012847: removing systemd preset file.
* Sun Jul  3 2016 i@marguerite.su
- add patch ooRexx-4.2.0-gcc6.patch, fixed boo#985384
  * 'false' is not convertible to a pointer in c++11, use
    'NULL' instead.
  * fixed name clash with gcc 6 cmath
  * upstream bug: https://sourceforge.net/p/oorexx/bugs/1380/ (fixed)
  * drop next release
- build with '-O0' instead of '-O2' to avoid segmentation fault.
  found by upstream in the same bug report but not yet fixed
- add patch ooRexx-chdir-setgroups.patch
  * chdir before chroot and setgroups before setuid
* Wed Jul 22 2015 emendonca@suse.com
- systemd-fixes.patch: Adds more fixes for the rxapid systemd service/preset as per SUSE's packaging guidelines. RXAPID now starts automatically as a systemd preset.
- Fixing wrong upstream permissions on REXX class files.
* Tue Jul 21 2015 perry.werneck@gmail.com
- Fixing up debian/Ubuntu build errors.
- Seens like .dsc just allow only one maintainer.
* Tue Jul 21 2015 emendonca@suse.com
- Fixing up debian build warnings and errors.
- Using autoreconf instead of bootstrap.
- Removing linefeed conversions, fixed upstream.
- Using latest 4.2.0 sources from Sourceforge.
* Tue Mar  3 2015 emendonca@suse.com
- Interpreter library links to .so files must be on the main package, as some older REXX applications load the SO by name.
* Fri Feb 20 2015 emendonca@suse.com
- Fixing BuildRequires for SLE12, as xalan-c is not available anymore.
* Thu Jan 22 2015 emendonca@suse.com
- Debian dsc file with wrong source archive name.
* Fri Jan  9 2015 emendonca@suse.com
- Links to some .so files were missing in the final RPM.
- Wrong link to /sbin/rcooRexx, should link to /usr/sbin/service as per packaging guidelines.
- Resolving conflicts.
* Thu Dec 18 2014 emendonca@suse.com
- rcooRexx should only be included with systemd-enabled systems. This was preventing a proper build on older systems.
* Wed Nov 19 2014 emendonca@suse.com
- Fixing systemd versus init.d dependencies.
* Thu Oct  9 2014 emendonca@suse.com
- new version 4.2.0
- A list of the bugs fixed upstream can be found at http://sourceforge.net/projects/oorexx/files/oorexx/4.2.0/CHANGES.txt/download
- removed fixes-rpmlint.patch, as it is no longer necessary (fixed upstream).
- removed update_init_script.patch, as it is no longer necessary (fixed upstream).
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
-  Follow the packaging guidelines.
* Mon Dec  9 2013 perry.werneck@gmail.com
- Updating to ooRexx 4.2.0 beta
* Thu Jul 11 2013 emendonca@suse.com
- New version based on 4.1.3. Lots of fixes for correct building as per SUSE's guidelines. A list of the bugs fixed upstream can be found at http://sourceforge.net/projects/oorexx/files/oorexx/4.1.3/CHANGES/download .
* Tue Apr  9 2013 emendonca@suse.com
- SPEC formatting tweaks.
* Mon Apr  8 2013 emendonca@suse.com
- adding exception for rpmlint. Build date in the interpreter is historical, cannot remove.
* Sun Apr  7 2013 emendonca@suse.com
- cleanups for Factory.
* Tue Oct 16 2012 emendonca@suse.com
- adding patches and spec fixes necessary for correct building.
* Tue Oct 16 2012 emendonca@suse.com
- adding patches and spec fixes necessary for correct building.
* Fri Oct 12 2012 emendonca@suse.com
- initial build based on release version 4.1.1 from oorexx.org.
